@@ -13,7 +13,7 @@ use Chart::Plotly::Trace::Box::Selected;
 use Chart::Plotly::Trace::Box::Stream;
 use Chart::Plotly::Trace::Box::Unselected;
 
-our $VERSION = '0.015';    # VERSION
+our $VERSION = '0.016';    # VERSION
 
 sub TO_JSON {
     my $self       = shift;
@@ -286,7 +286,7 @@ Chart::Plotly::Trace::Box
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -305,6 +305,18 @@ version 0.015
 
 In vertical (horizontal) box plots, statistics are computed using `y` (`x`) values. By supplying an `x` (`y`) array, one box per distinct x (y) value is drawn If no `x` (`y`) {array} is provided, a single box is drawn. That box position is then positioned with with `name` or with `x0` (`y0`) if provided. Each box spans from quartile 1 (Q1) to quartile 3 (Q3). The second quartile (Q2) is marked by a line inside the box. By default, the whiskers correspond to the box' edges +/- 1.5 times the interquartile range (IQR = Q3-Q1), see *boxpoints* for other options.
 
+Screenshot of the above example:
+
+=head1 NAME 
+
+Chart::Plotly::Trace::Box
+
+=for HTML <p>
+<img src="https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/box.png" alt="Screenshot of the above example">
+</p>
+
+=for markdown ![Screenshot of the above example](https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/box.png)
+
 This file has been autogenerated from the official plotly.js source.
 
 If you like Plotly, please support them: L<https://plot.ly/> 
@@ -312,10 +324,6 @@ Open source announcement: L<https://plot.ly/javascript/open-source-announcement/
 
 Full reference: L<https://plot.ly/javascript/reference/#box>
 
-=head1 NAME 
-
-Chart::Plotly::Trace::Box
-
 =head1 DISCLAIMER
 
 This is an unofficial Plotly Perl module. Currently I'm not affiliated in any way with Plotly. 
