@@ -12,7 +12,7 @@ use Chart::Plotly::Trace::Contour::Hoverlabel;
 use Chart::Plotly::Trace::Contour::Line;
 use Chart::Plotly::Trace::Contour::Stream;
 
-our $VERSION = '0.015';    # VERSION
+our $VERSION = '0.016';    # VERSION
 
 sub TO_JSON {
     my $self       = shift;
@@ -331,7 +331,7 @@ Chart::Plotly::Trace::Contour
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -356,6 +356,18 @@ version 0.015
 
 The data from which contour lines are computed is set in `z`. Data in `z` must be a {2D array} of numbers. Say that `z` has N rows and M columns, then by default, these N rows correspond to N y coordinates (set in `y` or auto-generated) and the M columns correspond to M x coordinates (set in `x` or auto-generated). By setting `transpose` to *true*, the above behavior is flipped.
 
+Screenshot of the above example:
+
+=head1 NAME 
+
+Chart::Plotly::Trace::Contour
+
+=for HTML <p>
+<img src="https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/contour.png" alt="Screenshot of the above example">
+</p>
+
+=for markdown ![Screenshot of the above example](https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/contour.png)
+
 This file has been autogenerated from the official plotly.js source.
 
 If you like Plotly, please support them: L<https://plot.ly/> 
@@ -363,10 +375,6 @@ Open source announcement: L<https://plot.ly/javascript/open-source-announcement/
 
 Full reference: L<https://plot.ly/javascript/reference/#contour>
 
-=head1 NAME 
-
-Chart::Plotly::Trace::Contour
-
 =head1 DISCLAIMER
 
 This is an unofficial Plotly Perl module. Currently I'm not affiliated in any way with Plotly. 
