@@ -10,7 +10,7 @@ use Chart::Plotly::Trace::Heatmapgl::Colorbar;
 use Chart::Plotly::Trace::Heatmapgl::Hoverlabel;
 use Chart::Plotly::Trace::Heatmapgl::Stream;
 
-our $VERSION = '0.015';    # VERSION
+our $VERSION = '0.016';    # VERSION
 
 sub TO_JSON {
     my $self       = shift;
@@ -272,7 +272,7 @@ Chart::Plotly::Trace::Heatmapgl
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -297,6 +297,18 @@ version 0.015
 
 WebGL version of the heatmap trace type.
 
+Screenshot of the above example:
+
+=head1 NAME 
+
+Chart::Plotly::Trace::Heatmapgl
+
+=for HTML <p>
+<img src="https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/heatmapgl.png" alt="Screenshot of the above example">
+</p>
+
+=for markdown ![Screenshot of the above example](https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/heatmapgl.png)
+
 This file has been autogenerated from the official plotly.js source.
 
 If you like Plotly, please support them: L<https://plot.ly/> 
@@ -304,10 +316,6 @@ Open source announcement: L<https://plot.ly/javascript/open-source-announcement/
 
 Full reference: L<https://plot.ly/javascript/reference/#heatmapgl>
 
-=head1 NAME 
-
-Chart::Plotly::Trace::Heatmapgl
-
 =head1 DISCLAIMER
 
 This is an unofficial Plotly Perl module. Currently I'm not affiliated in any way with Plotly. 
