@@ -17,7 +17,7 @@ use Chart::Plotly::Trace::Histogram::Unselected;
 use Chart::Plotly::Trace::Histogram::Xbins;
 use Chart::Plotly::Trace::Histogram::Ybins;
 
-our $VERSION = '0.015';    # VERSION
+our $VERSION = '0.016';    # VERSION
 
 sub TO_JSON {
     my $self       = shift;
@@ -278,7 +278,7 @@ Chart::Plotly::Trace::Histogram
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -293,6 +293,18 @@ version 0.015
 
 The sample data from which statistics are computed is set in `x` for vertically spanning histograms and in `y` for horizontally spanning histograms. Binning options are set `xbins` and `ybins` respectively if no aggregation data is provided.
 
+Screenshot of the above example:
+
+=head1 NAME 
+
+Chart::Plotly::Trace::Histogram
+
+=for HTML <p>
+<img src="https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/histogram.png" alt="Screenshot of the above example">
+</p>
+
+=for markdown ![Screenshot of the above example](https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/histogram.png)
+
 This file has been autogenerated from the official plotly.js source.
 
 If you like Plotly, please support them: L<https://plot.ly/> 
@@ -300,10 +312,6 @@ Open source announcement: L<https://plot.ly/javascript/open-source-announcement/
 
 Full reference: L<https://plot.ly/javascript/reference/#histogram>
 
-=head1 NAME 
-
-Chart::Plotly::Trace::Histogram
-
 =head1 DISCLAIMER
 
 This is an unofficial Plotly Perl module. Currently I'm not affiliated in any way with Plotly. 
