@@ -14,7 +14,7 @@ use Chart::Plotly::Trace::Pie::Outsidetextfont;
 use Chart::Plotly::Trace::Pie::Stream;
 use Chart::Plotly::Trace::Pie::Textfont;
 
-our $VERSION = '0.015';    # VERSION
+our $VERSION = '0.016';    # VERSION
 
 sub TO_JSON {
     my $self       = shift;
@@ -266,7 +266,7 @@ Chart::Plotly::Trace::Pie
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -282,6 +282,18 @@ version 0.015
 
 A data visualized by the sectors of the pie is set in `values`. The sector labels are set in `labels`. The sector colors are set in `marker.colors`
 
+Screenshot of the above example:
+
+=head1 NAME 
+
+Chart::Plotly::Trace::Pie
+
+=for HTML <p>
+<img src="https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/pie.png" alt="Screenshot of the above example">
+</p>
+
+=for markdown ![Screenshot of the above example](https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/pie.png)
+
 This file has been autogenerated from the official plotly.js source.
 
 If you like Plotly, please support them: L<https://plot.ly/> 
@@ -289,10 +301,6 @@ Open source announcement: L<https://plot.ly/javascript/open-source-announcement/
 
 Full reference: L<https://plot.ly/javascript/reference/#pie>
 
-=head1 NAME 
-
-Chart::Plotly::Trace::Pie
-
 =head1 DISCLAIMER
 
 This is an unofficial Plotly Perl module. Currently I'm not affiliated in any way with Plotly. 
