@@ -16,7 +16,7 @@ use Chart::Plotly::Trace::Scatter::Stream;
 use Chart::Plotly::Trace::Scatter::Textfont;
 use Chart::Plotly::Trace::Scatter::Unselected;
 
-our $VERSION = '0.015';    # VERSION
+our $VERSION = '0.016';    # VERSION
 
 sub TO_JSON {
     my $self       = shift;
@@ -349,7 +349,7 @@ Chart::Plotly::Trace::Scatter
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -364,6 +364,18 @@ version 0.015
 
 The scatter trace type encompasses line charts, scatter charts, text charts, and bubble charts. The data visualized as scatter point or lines is set in `x` and `y`. Text (appearing either on the chart or on hover only) is via `text`. Bubble charts are achieved by setting `marker.size` and/or `marker.color` to numerical arrays.
 
+Screenshot of the above example:
+
+=head1 NAME 
+
+Chart::Plotly::Trace::Scatter
+
+=for HTML <p>
+<img src="https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/scatter.png" alt="Screenshot of the above example">
+</p>
+
+=for markdown ![Screenshot of the above example](https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/scatter.png)
+
 This file has been autogenerated from the official plotly.js source.
 
 If you like Plotly, please support them: L<https://plot.ly/> 
@@ -371,10 +383,6 @@ Open source announcement: L<https://plot.ly/javascript/open-source-announcement/
 
 Full reference: L<https://plot.ly/javascript/reference/#scatter>
 
-=head1 NAME 
-
-Chart::Plotly::Trace::Scatter
-
 =head1 DISCLAIMER
 
 This is an unofficial Plotly Perl module. Currently I'm not affiliated in any way with Plotly. 
