@@ -16,7 +16,7 @@ use Chart::Plotly::Trace::Scatter3d::Projection;
 use Chart::Plotly::Trace::Scatter3d::Stream;
 use Chart::Plotly::Trace::Scatter3d::Textfont;
 
-our $VERSION = '0.015';    # VERSION
+our $VERSION = '0.016';    # VERSION
 
 sub TO_JSON {
     my $self       = shift;
@@ -299,7 +299,7 @@ Chart::Plotly::Trace::Scatter3d
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -326,6 +326,18 @@ version 0.015
 
 The data visualized as scatter point or lines in 3D dimension is set in `x`, `y`, `z`. Text (appearing either on the chart or on hover only) is via `text`. Bubble charts are achieved by setting `marker.size` and/or `marker.color` Projections are achieved via `projection`. Surface fills are achieved via `surfaceaxis`.
 
+Screenshot of the above example:
+
+=head1 NAME 
+
+Chart::Plotly::Trace::Scatter3d
+
+=for HTML <p>
+<img src="https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/scatter3d.png" alt="Screenshot of the above example">
+</p>
+
+=for markdown ![Screenshot of the above example](https://raw.githubusercontent.com/pablrod/p5-Chart-Plotly/master/examples/traces/scatter3d.png)
+
 This file has been autogenerated from the official plotly.js source.
 
 If you like Plotly, please support them: L<https://plot.ly/> 
@@ -333,10 +345,6 @@ Open source announcement: L<https://plot.ly/javascript/open-source-announcement/
 
 Full reference: L<https://plot.ly/javascript/reference/#scatter3d>
 
-=head1 NAME 
-
-Chart::Plotly::Trace::Scatter3d
-
 =head1 DISCLAIMER
 
 This is an unofficial Plotly Perl module. Currently I'm not affiliated in any way with Plotly. 
